﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace rbcom {
    class InfoCommand : rbcom.Command {

        protected bool ShowAll { get; set; }
        protected bool ShortMode { get; set; }

        public InfoCommand() : base() {
            this.Usage = String.Format("USAGE: {0} [options] RUBY_VERSION", this.Name);
            this.Description = @"管理下のRubyの情報を表示します";

            // オプション初期値
            this.ShowAll = false;
            this.ShortMode = false;

            // オプション
            this.Options.Add("a|all", "マッチしたRubyをすべて表示", delegate(string v) { this.ShowAll = true; });
            this.Options.Add("s|short", "簡易表示にします", delegate(string v) { this.ShortMode = true; });

            // 設定の保存はしない
            this.NoSaveConfiguration = true;
        }

        protected void ShowLongInformation(RubyProgram ruby, int number) {
            string information = @"
[Managed Ruby #{0}]
        Name : {1}
        Path : {2}
     Version : {3}
    Platform : {4}
Architecture : {5}
   Full Name : {1}-{3}-{4}
     Aliases : {6}

";

            System.Console.WriteLine(information.Trim(),
                number,
                ruby.Name, System.IO.Path.Combine(ruby.Location, ruby.Command),
                ruby.Version, ruby.Platform, ruby.Architecture,
                String.Join(@", ", (ruby.Aliases == null ? new HashSet<string>() : ruby.Aliases).ToArray().ToArray()));
            System.Console.WriteLine();
        }

        protected void ShowShortInformation(RubyProgram ruby, int number) {
            string information = @"#{0}:{1}-{2}-{3}";
            System.Console.WriteLine(information,
                number,
                ruby.Name,
                ruby.Version,
                ruby.Platform);
        }

        protected override bool Invoke(string[] args) {
            List<RubyProgram> rubies = this.Rubies.Find(args[0], true);
            if (rubies.Count == 0) {
                System.Console.Error.WriteLine("対象となるRubyが見つかりませんでした: {0}", args[0]);
                return false;
            }

            for (int i = 0; i < rubies.Count; i++) {
                RubyProgram ruby = rubies[i];

                if (this.ShortMode) {
                    this.ShowShortInformation(ruby, i);
                } else {
                    this.ShowLongInformation(ruby, i);
                }

                if (!this.ShowAll) {
                    break;
                }
            }

            return true;
        }

        protected override bool Validate(string[] args) {
            return (args.Length == 1);
        }

        static void Main(string[] args) {
            Run(new InfoCommand(), args);
        }
    }
}
