﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace rbcom {
    class ListCommand : rbcom.Command {

        public ListCommand() : base() {
            this.Usage = String.Format("USAGE: {0} [options] [RUBY_VERSION]", this.Name);
            this.Description = @"管理しているRubyの一覧を出力します

RUBY_VERSIONを指定した場合は、マッチしたRubyのみを出力します.

RUBY_VERSIONの形式は [{ruby}-]{x}[.{y}[.{z}]][-p{ddd}][-{platform}] です.
{}で囲われた部分は可変であり、[]で囲われた部分は省略可能部分です.
それぞれの意味は次のとおりです

  {ruby}        Ruby名 'ruby' だったり 'jruby' だったりします
  {x}.{y}.{z}   Rubyバージョン番号
  {ddd}         パッチレベル
  {platform}    Rubyの実装プラットフォーム (mswin32等)
";

            // 設定の保存はしない
            this.NoSaveConfiguration = true;
        }

        protected override bool Invoke(string[] args) {
            List<RubyProgram> rubies = null;
            if (args.Length > 0) {
                rubies = this.Rubies.Find(args[0]);
            } else {
                rubies = this.Rubies.Rubies;
            }
            foreach (RubyProgram ruby in rubies) {
                System.Console.Write("{0} {1} [{2}]", ruby.Name, ruby.Version, ruby.Platform);
                if (ruby.Aliases != null && ruby.Aliases.Count > 0) {
                    string aliases = String.Join(", ", ruby.Aliases.ToArray());
                    System.Console.Write(" (alias:{0})", aliases);
                }
                System.Console.WriteLine();
            }
            return true;
        }

        static void Main(string[] args) {
            Run(new ListCommand(), args);
        }
    }
}
