﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;

namespace rbcom {
    class WhereCommand : rbcom.Command {

        protected bool ShowLocation { get; set; }

        public WhereCommand() : base() {
            // 説明
            this.Usage = String.Format("USAGE: {0} [options] RUBY_VERSION", this.Name);
            this.Description = @"管理しているRubyのパスを表示します";

            // オプション
            this.Options.Add("l|location", @"コマンドのあるディレクトリを表示します", delegate(string v) { this.ShowLocation = true; });

            // 初期値
            this.ShowLocation = false;

            // 設定の保存はしない
            this.NoSaveConfiguration = true;
        }

        protected override bool Invoke(string[] args) {
            List<RubyProgram> rubies = this.Rubies.Find(args[0], true);
            if (rubies.Count == 0) {
                System.Console.Error.WriteLine("対象となるRubyが見つかりませんでした: {0}", args[0]);
                return false;
            } else {
                RubyProgram ruby = rubies[0];   // 先頭を使用

                if (this.ShowLocation) {
                    // ディレクトリのみ
                    System.Console.WriteLine(ruby.Location);
                } else {
                    // フルパス
                    System.Console.WriteLine(Path.Combine(ruby.Location, ruby.Command));
                }

                return true;
            }
        }

        protected override bool Validate(string[] args) {
            return (args.Length == 1);
        }

        static void Main(string[] args) {
            Run(new WhereCommand(), args);
        }
    }
}
